// EvalStats.cpp : Defines the entry point for the console application.
//
#include "stdafx.h"

#include <string>
#include <vector>
#include <istream>
#include <iostream>
#include <fstream>


using namespace std;

/** This is a small function which takes two log files and computes the
	difference in percent of the weighted render cost.
*/
bool extractRenderCost(ifstream &file, vector<float> &renderCosts)
{
	if (!file.is_open())
		return false;
		
	string buf;
	bool isRenderCost = false;

	while (!(getline(file, buf)).eof())
	{
		if (buf[0] == '#')
		{
			char entry[50];	

			sscanf(buf.c_str(), "#%s", entry);
			
			if (strcmp(entry, "TotalRenderCost") == 0)
				isRenderCost = true;
		}
		else if (isRenderCost)
		{
			float rc;
			sscanf(buf.c_str(), "%f", &rc);
			
			renderCosts.push_back(rc);
			isRenderCost = false;
		}
	}

	return true;
}

int _tmain(int argc, _TCHAR* argv[])
{
	vector<float> renderCosts1;
	vector<float> renderCosts2;
	
	if (argc < 4)
	{
		cerr << "arguments missing" << endl;
		exit(1);
	}


	// read two files and the output file

	// read file 1
	ifstream file1(argv[1]);

	// extract the render cost
	cout << "extracting render cost of file " << argv[1] << endl;
	cout.flush();
	extractRenderCost(file1, renderCosts1);

	// read file 2
    ifstream file2(argv[2]);
	cout << "extracting render cost of file " << argv[2] << endl;
	cout.flush();
	extractRenderCost(file2, renderCosts2);


	cout << "writing output to file " << argv[3] << endl;

	ofstream statsOut(argv[3]);

	//statsOut << "rc1 size: " << (int)renderCosts1.size() << " " << (int)renderCosts2.size() << endl << endl;
	int n = min((int)renderCosts1.size(), (int)renderCosts2.size());
	
	if (argc > 4)
	{
		char *endptr = NULL;
			
		int limit = strtol(argv[4], &endptr, 10);
		
		n = min(n, limit);
	}

	for (int i = 0; i < n; ++ i)
	{
		float costRatio = renderCosts2[i] != 0 ? 
			renderCosts1[i] / renderCosts2[i] : renderCosts1[i] / 0.0000001f;

		statsOut << "#ViewCells\n" << i + 1 << endl
				 << "#RenderCostRatio\n" << costRatio * 100.0f << endl;
	}

	return 0;
}

